
Sensitive information transmitted by un-encrypted methods
-------

**Description:**

Whenever sensitive information is send by unencrypted methods an attacker could intercept 
this data and use this for malicious intents.


**Solution:**

All sensitive information should always be send by an encrypted methods 
such as HTTPS connections.

Recommended knowledge base items:

- Secure session
- HTTP strict transport security
- HSTS preload
- Certificate pinning

	